import express from "express";
import bodyParser from "body-parser";
import { Server } from "socket.io";
import {createServer} from "http";
import model from "./model.js";
import start from "./controllers/start.controller.js";
import expressSession from "express-session";
import socketIOSession from "express-socket.io-session";
import { resolvePath } from "./util.js";

const port = 8989;
const app = express();
const server = createServer(app);
const io = new Server(server);

model.init(io);

app.use(bodyParser.json())

const sessionConf = expressSession({
    secret: "en strang for signering av kakan till syfte att undvika manipulering av kakan",
    resave: true, //tvingar att spara omodifierade session
   saveUninitialized: true, //tvingar att spara en ny session
});
app.use(sessionConf);
io.use(
  socketIOSession(sessionConf, {
    autoSave: true,
    saveUninitialized: true,
  })
);

app.use("/api",start.router);

const publicPath=resolvePath("client", "dist");
app.use(express.static(publicPath)); 

// Handle socket.io connections.
io.on("connection", (socket) => {
  const { session } = socket.handshake;
  session.socketID = socket.id;
  session.save((err) => {
    if (err) console.error(err);
    else console.debug(`Saved socketID: ${session.socketID}`);
  });
});


server.listen(port, () => {
  console.log(`Listening on http://localhost:${port}`);
});
